from typing import Optional


class FatWriter:
    def __init__(self): ...
    def add(self, data: bytes): ...
    def remove(self, arch: str) -> Optional[bytes]: ...
    def exists(self, arch: str) -> bool: ...
    def write_to(self, path: str): ...
    def generate(self) -> bytes: ...
